package cn.rankin.productservice.controller;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.dto.search.SearchDTO;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.product.WareDTO;
import cn.rankin.productservice.entity.Ware;
import cn.rankin.common.utils.enums.WareTypeEnum;
import cn.rankin.productservice.service.LessonService;
import cn.rankin.productservice.service.LessonWareRelationService;
import cn.rankin.productservice.service.WareService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

@RestController
@RequestMapping(value = "ware")
public class WareController {

    @Autowired
    private WareService wareService;

    @Autowired
    private LessonWareRelationService relationService;

    @Autowired
    private LessonService lessonService;

    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public APIResult<Page<Ware>> getWareList(SearchDTO searchDTO) {
        Ware ware = new Ware();

        String code = searchDTO.getCode();
        if (!StringUtils.isEmpty(code)) {
            ware.setCode("%" + code + "%");
        }

        String name = searchDTO.getName();
        if (!StringUtils.isEmpty(name)) {
            ware.setName("%" + name + "%");
        }

        ware.setType(searchDTO.getType());

        return wareService.search(ware, searchDTO.getPageNo(), searchDTO.getPageSize());
    }

    // 创建资源
    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Ware> create(@Valid @RequestBody WareDTO wareDTO) {
        String code = wareDTO.getCode();
        WareTypeEnum type = wareDTO.getType();
        if (StringUtils.isEmpty(code) || type == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return wareService.create(wareDTO);
    }

    // 修改资源
    @RequestMapping(method = RequestMethod.PUT)
    public APIResult<Ware> update(@Valid @RequestBody WareDTO wareDTO) {
        if (wareDTO.getId() == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return wareService.update(wareDTO);
    }

    // 删除资源
    @RequestMapping(value = "/{id}", method = RequestMethod.DELETE)
    public APIResult<Boolean> delete(@NotNull @PathVariable("id") String id) {
        return wareService.delete(id);
    }

    // 取一个
    @RequestMapping(value = "/{id}", method = RequestMethod.GET)
    public APIResult<Ware> getWare(@PathVariable("id") String id) {
        return wareService.findById(id);
    }

}
