package cn.rankin.productservice.entity;

import cn.rankin.common.utils.enums.BaseStatusEnum;
import cn.rankin.common.utils.enums.WareTypeEnum;
import lombok.Data;
import lombok.ToString;
import org.apache.commons.lang.StringUtils;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Data
@ToString
@Entity
@Table(name = "lj_ware")
@DynamicInsert
@DynamicUpdate
public class Ware implements Serializable{

    @Id
    private String id;

    @Column(nullable = false, unique = true)
    private String code;

    @Column
    private String name;

    @Column
    private String digest;

    @Column
    @Enumerated(EnumType.ORDINAL)
    private WareTypeEnum type;

    @Column(name = "play_url")
    private String playUrl;

    @Column(name = "img_ids")
    @Convert(converter = ListAttributeConverter.class)
    private List<String> imgIds;

    @Column(name = "cp_id")
    private String cpId;

    @Column
    private Integer sort;

    @Column
    @Enumerated(EnumType.ORDINAL)
    private BaseStatusEnum status;

    @Column(name = "gmt_created", updatable = false, insertable = false, columnDefinition = "timestamp NULL DEFAULT CURRENT_TIMESTAMP")
    @Temporal(TemporalType.TIMESTAMP)
    private Date gmtCreated;

    @Column(name = "gmt_modified", updatable = false, insertable = false, columnDefinition = "timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP")
    @Temporal(TemporalType.TIMESTAMP)
    private Date gmtModified;

    // Attribute converter: List to String
    public static class ListAttributeConverter implements AttributeConverter<List<String>, String> {

        @Override
        public String convertToDatabaseColumn(List<String> attr) {
            Long start = System.currentTimeMillis();
            if (attr == null || attr.size() == 0) {
                return "";
            }

            StringBuilder builder = new StringBuilder("");
            attr.forEach( s -> builder.append(s + ","));
            String value = builder.toString();

            return value.substring(0, value.length()-1);
        }

        @Override
        public List<String> convertToEntityAttribute(String value) {
            if (StringUtils.isEmpty(value)) {
                return new ArrayList<>();
            }

            List<String> attr = new ArrayList<>();
            for (String s: value.split(",")) {
                attr.add(s);
            }

            return attr;
        }
    }

}

